from django.apps import AppConfig


class FirebaseAdminMcpConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'firebase_admin_mcp'
    verbose_name = 'Firebase Admin MCP'
